/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetJDBCDatasourceInfoCommand.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */

/**
 * Gets the JDBC datasource info
 * @author Florent Benoit
 */
package org.ow2.jonas.admin.jdbcconnections.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;

import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.ResultEvent;

import org.ow2.jonas.admin.jdbcconnections.business.IGetJDBCDatasourceInfoDelegate;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCDatasourceInfoEvent;
import org.ow2.jonas.admin.jdbcconnections.model.JDBCConnectionsModelLocator;
import org.ow2.jonas.admin.jdbcconnections.vo.JDBCDatasourceInfoVO;


public class GetJDBCDatasourceInfoCommand extends AbsCommand implements ICommand, IResponder {


    /**
     * Execute the action.
     */
    public function execute(event : CairngormEvent) : void {
		try {
        // Ask the delegate
        var delegate : IGetJDBCDatasourceInfoDelegate = JDBCConnectionsModelLocator.getInstance().jdbcDatasourceInfoDelegate;
        
          // Extract info from the event
		   var datasourceInfoEvent : GetJDBCDatasourceInfoEvent = event as GetJDBCDatasourceInfoEvent;

        
        delegate.responder = this;
        delegate.getJDBCDatasourceInfo(datasourceInfoEvent.value);
    	} catch(e:Error){
    		Alert.show("error " + e);
     		trace("An error occurred: " + e.message);
     	}
    }

    /**
     * Manage the result found by a delegate.
     */
    public function result(event : Object) : void {
        // value is contained in the event
        var resultEvent : ResultEvent = event as ResultEvent;

  		// Get Value Object from the result
        var datasourceInfoVO : JDBCDatasourceInfoVO = resultEvent.result as JDBCDatasourceInfoVO;

        // Gets the Model
        var model : JDBCConnectionsModelLocator = JDBCConnectionsModelLocator.getInstance();

        // Sets the Value Object on the model
       model.datasourceInfo = datasourceInfoVO;

    }



}
}