/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SetForceCloseJNDIInterceptorsConfigurationCommand.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */

/**
 * Gets the JNDI Interceptors configuration
 * @author Florent Benoit
 */
package org.ow2.jonas.admin.jdbcconnections.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.ResultEvent;

import org.ow2.jasmine.kerneos.common.event.KerneosNotificationEvent;
import org.ow2.jonas.admin.jdbcconnections.business.ISetForceCloseJNDIInterceptorsConfigurationDelegate;
import org.ow2.jonas.admin.jdbcconnections.event.GetJNDIInterceptorsConfigurationEvent;
import org.ow2.jonas.admin.jdbcconnections.event.SetForceCloseJNDIInterceptorsEvent;
import org.ow2.jonas.admin.jdbcconnections.event.SetRegexpValueJNDIInterceptorsEvent;
import org.ow2.jonas.admin.jdbcconnections.model.JDBCConnectionsModelLocator;


public class SetForceCloseJNDIInterceptorsConfigurationCommand extends AbsCommand implements ICommand, IResponder {

    /**
     * Execute the action.
     */
    public function execute(event : CairngormEvent) : void {
        try {
            // Ask the delegate
            var delegate : ISetForceCloseJNDIInterceptorsConfigurationDelegate = JDBCConnectionsModelLocator.getInstance().jndiInterceptorsSetForceCloseValueDelegate;

            // Extract info from the event
		   var forceCloseEvent : SetForceCloseJNDIInterceptorsEvent = event as SetForceCloseJNDIInterceptorsEvent;

            delegate.responder = this;
            delegate.updateForceClose(forceCloseEvent.value);
        } catch (e : Error) {
            Alert.show("error " + e);
            trace("An error occurred: " + e.message);
        }
    }

    /**
     * Manage the result found by a delegate.
     */
    public function result(event : Object) : void {
        // value is contained in the event
        var resultEvent : ResultEvent = event as ResultEvent;

		// Change has been done successfully !
        JDBCConnectionsModelLocator.getInstance().dispatch(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION, "Value for the forceClose option of the JDBC JNDI Interceptor component has been updated", KerneosNotificationEvent.INFO));


        // We have updated the value, needs to refresh the configuration
        var configEvent : GetJNDIInterceptorsConfigurationEvent = new GetJNDIInterceptorsConfigurationEvent(GetJNDIInterceptorsConfigurationEvent.EVENT_GET_JNDI_INTERCEPTORS_CONFIGURATION + JDBCConnectionsModelLocator.getInstance().componentID);
        CairngormEventDispatcher.getInstance().dispatchEvent(configEvent);
    }



}
}