/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Controller.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.jdbcconnections.control {

import com.adobe.cairngorm.control.FrontController;

import org.ow2.jonas.admin.jdbcconnections.command.*;
import org.ow2.jonas.admin.jdbcconnections.event.*;
import org.ow2.jonas.admin.jdbcconnections.model.*;


/**
 * Bind a type of command to an action.
 * @author Florent Benoit
 */
public class Controller extends FrontController {

    // =====================================================================
    // Initialization
    // =====================================================================

    /**
     * Create an instance of the controller. Commands are initialized here.
     */
    public function Controller() {
        initialiseCommands();
    }

    /**
     * Add all the commands to the pool of commands.
     *
     * An unique ID was added to all the events in order
     * to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public function initialiseCommands() : void {
        // Retrieve the component model
        var model : JDBCConnectionsModelLocator = JDBCConnectionsModelLocator.getInstance();
       	this.addCommand(GetJNDIInterceptorsConfigurationEvent.EVENT_GET_JNDI_INTERCEPTORS_CONFIGURATION + model.componentID, GetJNDIInterceptorsConfigurationCommand);
       	this.addCommand(SetRegexpValueJNDIInterceptorsEvent.EVENT_SET_REGEXP_VALUE_JNDIINTERCEPTORS_CONFIGURATION + model.componentID, SetRegexpJNDIInterceptorsConfigurationCommand);
       	this.addCommand(SetForceCloseJNDIInterceptorsEvent.EVENT_SET_FORCE_CLOSE_JNDIINTERCEPTORS_CONFIGURATION + model.componentID, SetForceCloseJNDIInterceptorsConfigurationCommand);
       	this.addCommand(GetJDBCDatasourcesEvent.EVENT_GET_JDBC_DATASOURCES + model.componentID, GetJDBCDatasourcesCommand);
       	this.addCommand(GetJDBCDatasourceInfoEvent.EVENT_GET_JDBC_DATASOURCE_INFO + model.componentID, GetJDBCDatasourceInfoCommand);
       	this.addCommand(GetJDBCConnectionsInfosEvent.EVENT_GET_JDBC_CONNECTIONS_INFO + model.componentID, GetJDBCConnectionsInfoCommand);
       	this.addCommand(KillAJDBCConnectionEvent.EVENT_KILL_A_JDBC_CONNECTION + model.componentID, KillAJDBCConnectionCommand);
       	this.addCommand(SetObservableDataSourceEvent.EVENT_SET_OBSERVABLE_ON_DATASOURCE + model.componentID, SetObservableDataSourceCommand);
       	
    }
}
}
