/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JDBCConnectionsClass.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.jdbcconnections.view {

import com.adobe.cairngorm.control.CairngormEventDispatcher;

import flash.events.Event;
import flash.events.TimerEvent;
import flash.utils.Timer;

import mx.containers.VBox;
import mx.controls.Alert;
import mx.controls.CheckBox;
import mx.controls.DataGrid;
import mx.controls.TextInput;
import mx.controls.Tree;
import mx.events.FlexEvent;

import org.ow2.jasmine.kerneos.common.event.KerneosNotificationEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCConnectionsInfosEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCDatasourceInfoEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCDatasourcesEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJNDIInterceptorsConfigurationEvent;
import org.ow2.jonas.admin.jdbcconnections.event.SetForceCloseJNDIInterceptorsEvent;
import org.ow2.jonas.admin.jdbcconnections.event.SetObservableDataSourceEvent;
import org.ow2.jonas.admin.jdbcconnections.event.SetRegexpValueJNDIInterceptorsEvent;
import org.ow2.jonas.admin.jdbcconnections.model.JDBCConnectionsModelLocator;


/**
 * Defines the parent class of the MXML component.
 * @author Florent Benoit
 */
public class JDBCConnectionsClass extends VBox {

    /**
     * Model used for this view.
     */
    [Bindable]
    public var model : JDBCConnectionsModelLocator = JDBCConnectionsModelLocator.getInstance();


    /**
     * Tree that will display the JDBC Datasources selecting nodes.
     */
    [Bindable]
    public var jdbcDatasourcesSelectedTree : Tree;


    /**
     * TextInput for the regexp value.
     */
    [Bindable]
    public var regexpTextField : TextInput;

    /**
     * CheckBox for the forceClose option.
     */
    [Bindable]
    public var forceCloseCheckBox : CheckBox;

    /**
     * CheckBox for the observable option.
     */
    [Bindable]
    public var idObservableDataSource : CheckBox;


    /**
     * Datagrid
     */
    [Bindable]
    public var idDatagridConnections : DataGrid;


    [Bindable]
    // Component that will display the MBean attributes.
    public var dgAttributes : DataGrid;


    [Bindable]
    public var startedModule : Boolean = false;

    public var timer : Timer = null;

    private var timerLength : Number = 10;



    /**
     * Initates the module.
     */

    protected function init() : void {
		// Start the timer
		startTimer();

        // Dispatch a notification to Kerneos
        dispatchEvent(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION, "JDBC Connections Leaks Module Initialized", KerneosNotificationEvent.DEBUG));
    }


    /**
     * Default constructor.
     */
    public function JDBCConnectionsClass() : void {
        addEventListener(FlexEvent.CREATION_COMPLETE, creationCompleteHandler);
    }


    /**
     * Handler called when object is created.
     */
    private function creationCompleteHandler(event : FlexEvent) : void {


    }


    /**
     * Ask the update of the JNDI Interceptors configuration
     */
    protected function updateJNDIInterceptorsConfiguration() : void {
        var event : GetJNDIInterceptorsConfigurationEvent = new GetJNDIInterceptorsConfigurationEvent(GetJNDIInterceptorsConfigurationEvent.EVENT_GET_JNDI_INTERCEPTORS_CONFIGURATION + model.componentID);
        CairngormEventDispatcher.getInstance().dispatchEvent(event);
    }


    /**
     * Ask the update of the JDBC Datasources
     */
    protected function updateJDBCDatasources() : void {
        var event : GetJDBCDatasourcesEvent = new GetJDBCDatasourcesEvent(GetJDBCDatasourcesEvent.EVENT_GET_JDBC_DATASOURCES + model.componentID);
        CairngormEventDispatcher.getInstance().dispatchEvent(event);
    }


    protected function changeRegexpValue(event : Event) : void {
        var newValue : String = regexpTextField.text;
        var setRegexpEvent : SetRegexpValueJNDIInterceptorsEvent = new SetRegexpValueJNDIInterceptorsEvent(SetRegexpValueJNDIInterceptorsEvent.EVENT_SET_REGEXP_VALUE_JNDIINTERCEPTORS_CONFIGURATION + model.componentID, newValue);
        CairngormEventDispatcher.getInstance().dispatchEvent(setRegexpEvent);

    }

    protected function changeForceCloseValue(event : Event) : void {
        var newValue : Boolean = forceCloseCheckBox.selected;
        var setForceCloseEvent : SetForceCloseJNDIInterceptorsEvent = new SetForceCloseJNDIInterceptorsEvent(SetForceCloseJNDIInterceptorsEvent.EVENT_SET_FORCE_CLOSE_JNDIINTERCEPTORS_CONFIGURATION + model.componentID, newValue);
        CairngormEventDispatcher.getInstance().dispatchEvent(setForceCloseEvent);
    }

    protected function changeObservableValue(event : Event) : void {
        var objectName : String = model.selectedJDBCDatasourceObjectName;
        var newValue : Boolean = idObservableDataSource.selected;
        var setObservableEvent : SetObservableDataSourceEvent = new SetObservableDataSourceEvent(SetObservableDataSourceEvent.EVENT_SET_OBSERVABLE_ON_DATASOURCE + model.componentID, objectName, newValue);
        CairngormEventDispatcher.getInstance().dispatchEvent(setObservableEvent);
    }



    /**
     * Called when the selected element of the Datasource tree is changed
     */
    public function jdbcDatasourcesSelectionChange(event : Event) : void {

        // Event is an XML object
        var selectedNode : XML = event.target.selectedItem as XML;

        // Do something only if node selected is named "item"
        if (selectedNode != null && selectedNode.name() == "item") {

            // Change the name of the selected ObjectName
            model.selectedJDBCDatasourceObjectName = selectedNode.attribute("objectName");

            sendEventRefreshDataSourceInfo();
            // ...and the connections info
            sendEventRefreshConnectionsInfo();

        } else {
            // reset values
            resetJDBCValues();
        }
    }

    private function sendEventRefreshDataSourceInfo() : void {
    	if (model.selectedJDBCDatasourceObjectName != null) {
        // Send an event to get datasource infos
        var getDatasourceInfoEvent : GetJDBCDatasourceInfoEvent = new GetJDBCDatasourceInfoEvent(GetJDBCDatasourceInfoEvent.EVENT_GET_JDBC_DATASOURCE_INFO + model.componentID, model.selectedJDBCDatasourceObjectName);
        CairngormEventDispatcher.getInstance().dispatchEvent(getDatasourceInfoEvent);
     }
    }

    private function sendEventRefreshConnectionsInfo() : void {
    	if (model.selectedJDBCDatasourceObjectName != null) {
    		
     // Send an event to get connection infos
        var getConnectionInfoEvent : GetJDBCConnectionsInfosEvent = new GetJDBCConnectionsInfosEvent(GetJDBCConnectionsInfosEvent.EVENT_GET_JDBC_CONNECTIONS_INFO + model.componentID, model.selectedJDBCDatasourceObjectName, 0);
        CairngormEventDispatcher.getInstance().dispatchEvent(getConnectionInfoEvent);
            	}   
    }


    /**
     * Timers is occuring, needs to refresh the selected data
     */
    public function timerRefresh(event : TimerEvent = null) : void {

        if (startedModule == true) {

            // If refresh datasources :
            if (model.refreshListDatasources) {
                updateJDBCDatasources();
            }

            if (model.refreshDatasourceInfo) {
                sendEventRefreshDataSourceInfo();
            }

            if (model.refreshJdbcConnectionsInfo) {
                sendEventRefreshConnectionsInfo();
            }

        }

    }

    /**
     * Start timer.
     */
    private function startTimer() : void {
        // First stop the timer if needed
        stopTimer();

        // Recreate it and start it
        timer = new Timer(this.timerLength * 1000, Infinity);
        timer.addEventListener(TimerEvent.TIMER, timerRefresh);
        startedModule = true;

        // Dispatch a notification to Kerneos
        dispatchEvent(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION, "Start the timer that refresh data automatically", KerneosNotificationEvent.DEBUG));

        timer.start();
    }



    /**
     * Stop the refresh timer
     */
    public function stopTimer() : void {
        // If the timer was started, destroy it
        if (timer != null) {
            if (timer.running) {
                timer.stop();
            }

            // Dispatch a notification to Kerneos
            dispatchEvent(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION, "Stop the timer that refresh data automatically", KerneosNotificationEvent.DEBUG));

            timer = null;
        }
        startedModule = false;
    }


    protected function resetJDBCValues() : void {
        // reset values
        model.selectedJDBCDatasourceObjectName = null;
        model.datasourceInfo = null;
        model.activeJDBCConnectionsInfoArrayCollectionVO = null;
    }


    protected function killConnection() : void {
        Alert.show("Killing connection with ID " + id);
    }

    public static function getDifferenceDate(difference : Number) : String {
        if (difference < 0) {
            return "N/A";
        }


        var value : String = "";
        var days : Number = Math.round(difference / 86400000);
        var hours : Number = Math.floor((difference - (days * 86400000)) / (3600000));
        var minutes : Number = Math.floor((difference - (days * 86400000) - (hours * 3600000)) / (60000));
        var seconds : Number = Math.floor((difference - (days * 86400000) - (hours * 3600000) - (minutes * 60000)) / (1000));
        if (days > 0) {
            value += days + " days";
        }
        if (hours > 0) {
            if (value != "") {
                value += ", ";
            }
            value += hours + " hours";
        }
        if (minutes > 0) {
            if (value != "") {
                value += ", ";
            }
            value += minutes + " minutes";
        }
        if (seconds > 0) {
            if (value != "") {
                value += ", ";
            }
            value += seconds + " seconds";
        }
        if (value != "") {
            value += ".";
        }

        return value;
    }



	public static function extractStackTraceLines(text : String, lastLine : Boolean) : String {
		var newText : String = "";
		var lines : Array = text.split("\n");
		
		// Search the last getConnection() call in the lines containing ow2 JOnAS code
		var lastCallToGetConnectionLine : int = 0;
		var pattern:RegExp = /getConnection/;
		var patternOW2:RegExp = /org.ow2.jonas./;
		
		for (var i : int = 0; i < lines.length; i++) {
			var line : String = lines[i];
			// Start by JOnAS code
			if (line.search(patternOW2)) {
				if (line.search(pattern) != -1) {
					lastCallToGetConnectionLine = i;
				}
			}
		}
		
		// Now remove all lines before the last call (including the last call line)
		if (!lastLine) {
		for (var l : int = lastCallToGetConnectionLine + 1; l <lines.length; l++) {
			newText += lines[l] + "\n";
		}
		} else {
			return lines[lastCallToGetConnectionLine + 1];
		}
		
		return newText;
	}
	


}
}
