/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RefreshPanel.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.jdbcconnections.view {

import com.adobe.cairngorm.control.CairngormEventDispatcher;

import flash.events.MouseEvent;

import mx.collections.ArrayCollection;
import mx.containers.HBox;
import mx.containers.Panel;
import mx.controls.Button;
import mx.controls.CheckBox;
import mx.controls.LinkButton;
import mx.effects.Resize;

import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCConnectionsInfosEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCDatasourceInfoEvent;
import org.ow2.jonas.admin.jdbcconnections.event.KillAJDBCConnectionEvent;
import org.ow2.jonas.admin.jdbcconnections.model.JDBCConnectionsModelLocator;
import org.ow2.jonas.admin.jdbcconnections.vo.JDBCConnectionInfoVO;

/**
 * Panel that is allowing to put some buttons like refresh/minimize, etc
 * @author Florent Benoit
 */ 
public class RefreshPanel extends Panel {

	/**
	 * Right control box
	 */ 
    private var controlBox : HBox = null;

	/**
	 * Left control box
	 */ 
    private var leftControlBox : HBox = null;
    
    /**
    * Automatic refresh checkbox.
    */ 
    private var refreshCheckBox : CheckBox = null;

	/**
	 * Toggle Details button.
	 */ 
    private var toggleDetailsButton : Button = null;

	/**
	 * Toggle size button.
	 */ 
    private var toggleSizeButton : Button = null;

	/**
	 * Kill All button.
	 */ 
    private var killAllButton : Button = null;

	/**
	 * Mode for the refresh operation ?
	 */ 
    public var jdbcConnectionsMode : Boolean = true;

	/**
	 * Model used by this panel.
	 */ 
    private var model : JDBCConnectionsModelLocator;

	/**
	 * Empty icon to add left space
	 */ 
    [Embed("/../assets/empty.png")]
    private const emptyTitleIcon : Class;

	/**
	 * Arrow for maximize
	 */ 
    [Embed("/../assets/arrow-maximize.png")]
    private const arrowMaximizeIcon : Class;

	/**
	 * Arrow for minimize
	 */ 
    [Embed("/../assets/arrow-minimize.png")]
    private const arrowMinimizeIcon : Class;

	/**
	 * Is that the panel is maximized ?
	 */ 
    private var maximized : Boolean = true;
    
    /**
    * Height before minimizing
    */ 
    private var originalHeight : int = 0;

	/**
	 * Constructor
	 */ 
    public function RefreshPanel() {
        super();
        this.model = JDBCConnectionsModelLocator.getInstance();
    }

    protected function showAdvancedDetailsItem(event : MouseEvent) : void {
        // Toggle mode
        if (model.showAdvancedJDBCConnectionsInfo) {
            model.showAdvancedJDBCConnectionsInfo = false;
            toggleDetailsButton.label = "Show Advanced Details";
        } else {
            model.showAdvancedJDBCConnectionsInfo = true;
            toggleDetailsButton.label = "Hide Advanced Details";
        }
        refreshJDBCConnectionsInfo();
    }
    
	protected function killAllConnections(event : MouseEvent) : void {
       var collection : ArrayCollection = model.activeJDBCConnectionsInfoArrayCollectionVO;
       if (collection != null && collection.length > 0) {
       		for (var i : int = 0; i < collection.length; i++) {
       			var jdbcConnectionInfo : JDBCConnectionInfoVO = collection[i];
      			
		        var objectName : String = model.selectedJDBCDatasourceObjectName;
                 // Send the order to kill a connection
                var killEvent : KillAJDBCConnectionEvent = new KillAJDBCConnectionEvent(KillAJDBCConnectionEvent.EVENT_KILL_A_JDBC_CONNECTION + model.componentID, objectName, jdbcConnectionInfo.id);
                CairngormEventDispatcher.getInstance().dispatchEvent(killEvent);

       		}  
       }
        refreshJDBCConnectionsInfo();
    }
    

    protected function refreshJDBCConnectionsInfo() : void {
        var infoConnectionEvent : GetJDBCConnectionsInfosEvent = new GetJDBCConnectionsInfosEvent(GetJDBCConnectionsInfosEvent.EVENT_GET_JDBC_CONNECTIONS_INFO + model.componentID, model.selectedJDBCDatasourceObjectName, 0);
        CairngormEventDispatcher.getInstance().dispatchEvent(infoConnectionEvent);
    }


    protected function refreshItem(event : MouseEvent) : void {

        // Enable/disable automatic Refresh of JDBC Datasource info
        if (!jdbcConnectionsMode) {
            model.refreshDatasourceInfo = refreshCheckBox.selected;
        }

        // Enable/disable automatic Refresh of JDBC Connections info
        if (jdbcConnectionsMode) {
            model.refreshJdbcConnectionsInfo = refreshCheckBox.selected;

        }
    }

    protected function updateStyleToggleButton() : void {
        if (maximized) {
            toggleSizeButton.setStyle("icon", arrowMinimizeIcon);
            toggleSizeButton.setStyle("upicon", arrowMinimizeIcon);
            toggleSizeButton.setStyle("overIcon", arrowMinimizeIcon);
        } else {
            toggleSizeButton.setStyle("icon", arrowMaximizeIcon);
            toggleSizeButton.setStyle("upicon", arrowMaximizeIcon);
            toggleSizeButton.setStyle("overIcon", arrowMaximizeIcon);
        }
    }


    protected function toggleEvent(event : MouseEvent) : void {
        maximized = !maximized;
        updateStyleToggleButton();

        // Resize
        if (!maximized) {
           var minResize : Resize = new Resize();
            minResize.target = this;
            minResize.duration = 300;
            this.originalHeight = this.height;
            minResize.heightTo = 30;
            minResize.end();
            minResize.play();
        } else {
           var maxResize : Resize = new Resize();
            maxResize.target = this;
            maxResize.duration = 300;
            if (originalHeight > measuredHeight) {
                maxResize.heightTo = originalHeight;
            } else {
            	maxResize.heightTo = measuredHeight;
            }
            maxResize.end();
            maxResize.play();
        }


    }

    override protected function createChildren() : void {
        super.createChildren();


        if (!this.leftControlBox) {
            this.leftControlBox = new HBox();
            // Put controls on the right and vertical align to middle
            this.leftControlBox.setStyle("horizontalAlign", "left");
            this.leftControlBox.setStyle("verticalAlign", "middle");
            this.titleBar.addChild(leftControlBox);

            if (!toggleSizeButton) {
                toggleSizeButton = new LinkButton();
                updateStyleToggleButton()
                toggleSizeButton.setStyle("rollOverColor", this.getStyle("backgroundColor"));
                toggleSizeButton.setStyle("selectionColor", this.getStyle("backgroundColor"));
                toggleSizeButton.addEventListener(MouseEvent.CLICK, toggleEvent);
                leftControlBox.addChild(toggleSizeButton);
            }

        }



        if (!this.controlBox) {

            this.titleIcon = emptyTitleIcon;


            this.controlBox = new HBox();
            // Put controls on the right and vertical align to middle
            this.controlBox.setStyle("horizontalAlign", "right");
            this.controlBox.setStyle("verticalAlign", "middle");
            this.titleBar.addChild(controlBox);
        }

        if (jdbcConnectionsMode) {
        	if (!killAllButton) {
                killAllButton = new Button();
                killAllButton.label = "Close All";
                killAllButton.toolTip = "Close All JDBC Connections";
                killAllButton.addEventListener(MouseEvent.CLICK, killAllConnections);
                controlBox.addChild(killAllButton);
        		
        	}
        	
            if (!toggleDetailsButton) {
                toggleDetailsButton = new Button();
                toggleDetailsButton.label = "Show Advanced Details";
                toggleDetailsButton.toolTip = "Display/Hide details of JDBC Connections";
                toggleDetailsButton.addEventListener(MouseEvent.CLICK, showAdvancedDetailsItem);
                controlBox.addChild(toggleDetailsButton);
            }

        }


        if (!refreshCheckBox) {
            refreshCheckBox = new CheckBox();
            refreshCheckBox.selected = true;
            refreshCheckBox.label = "Auto Refresh";
            refreshCheckBox.toolTip = "Refresh the data automatically";
            refreshCheckBox.addEventListener(MouseEvent.CLICK, refreshItem);
            controlBox.addChild(refreshCheckBox);
        }
    }


    override protected function updateDisplayList(unscaledWidth : Number, unscaledHeight : Number) : void {
        super.updateDisplayList(unscaledWidth, unscaledHeight);

        // update control box
        this.controlBox.y = titleBar.y;
        this.controlBox.width = unscaledWidth;
        this.controlBox.height = titleBar.height;

        // update control box
        this.leftControlBox.y = titleBar.y;
        this.leftControlBox.width = unscaledWidth;
        this.leftControlBox.height = titleBar.height;
    }


}
}
